local assets=
{ 
    Asset("ANIM", "anim/busteraxe.zip"),
    Asset("ANIM", "anim/swap_busteraxe.zip"), 

    Asset("ATLAS", "images/inventoryimages/busteraxe.xml"),
    Asset("IMAGE", "images/inventoryimages/busteraxe.tex"),
}

local prefabs = 
{
"axe",
"goldenaxe",
"lucy",
}

--TUNING.BUSTERAXE_DAMAGE = TUNING.SPIKE_DAMAGE * 3
TUNING.BUSTERAXE_DAMAGE = 76
TUNING.BUSTERAXE_RANGE = 1.05
TUNING.BUSTERAXE_CHOP = 4

TUNING.BUSTERAXE_POND_MOD =  require("aoa_pond_mod")



local function updateStatus(inst)
	local c = TUNING.BUSTERAXE_CHOP + inst.lucyCnt*2
    inst.components.tool:SetAction(ACTIONS.CHOP, c)
end



local function onsave(inst, data)
    data.oncePickUpped = inst.oncePickUpped
    data.lucyCnt = inst.lucyCnt
end



local function onload(inst, data)
    if data then
        inst.oncePickUpped = data.oncePickUpped or false
    	inst.lucyCnt = data.lucyCnt or 0
		updateStatus(inst)

        -- stop shining itself
        if inst.oncePickUpped then
            inst.AnimState:SetBloomEffectHandle( "" )
        end
    end
end



local function onattack(inst, attacker, target, skipsanity)
--    attacker.components.playercontroller:ShakeCamera(inst, "FULL", 0.25, 0.03, 0.25, 6)
--    TheInputProxy:AddVibration(VIBRATION_BLOOD_FLASH, 0.25, 0.2, false)    
--    attacker.components.hunger:DoDelta(-TUNING.BUSTERAXE_COST)
end



local function fn(colour)

    local function OnEquip(inst, owner) 
        -- stop shining itself
        if not inst.oncePickUpped then
            inst.AnimState:SetBloomEffectHandle( "" )
            inst.oncePickUpped = true
        end

        --owner.AnimState:OverrideSymbol("swap_object", "swap_wands", "purplestaff")
        owner.AnimState:OverrideSymbol("swap_object", "swap_busteraxe", "wand")
        owner.AnimState:Show("ARM_carry") 
        owner.AnimState:Hide("ARM_normal") 
    end

    local function OnUnequip(inst, owner) 
        owner.AnimState:Hide("ARM_carry") 
        owner.AnimState:Show("ARM_normal") 
    end

    local inst = CreateEntity()
    local trans = inst.entity:AddTransform()
    local anim = inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    MakeInventoryPhysics(inst)
    
    anim:SetBank("busteraxe")
    anim:SetBuild("busteraxe")
    anim:PlayAnimation("idle")

    inst:AddTag("sharp")

    inst:AddComponent("weapon")
    inst.components.weapon:SetDamage(TUNING.BUSTERAXE_DAMAGE)
    inst.components.weapon:SetRange(TUNING.BUSTERAXE_RANGE)
    inst.components.weapon:SetOnAttack(onattack)

    inst:AddComponent("tool")
    inst.components.tool:SetAction(ACTIONS.CHOP, 4)

    inst:AddComponent("inspectable")

    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.imagename = "busteraxe"
    inst.components.inventoryitem.atlasname = "images/inventoryimages/busteraxe.xml"
    
    inst:AddComponent("equippable")
    inst.components.equippable:SetOnEquip( OnEquip )
    inst.components.equippable:SetOnUnequip( OnUnequip )

    inst:AddComponent("trader")
    inst.components.trader:SetAcceptTest(function(inst, item) return item and (item.prefab=="lucy") end)
    inst.components.trader.onaccept=function(inst,giver,item)
        if item.prefab == "lucy" then
            inst.lucyCnt = inst.lucyCnt + 1
            inst.SoundEmitter:PlaySound("dontstarve/characters/wx78/levelup")
        end
        updateStatus(inst)
    end
    inst.components.trader.onrefuse=function(inst,giver,item) if giver.components.talker then giver.components.talker:Say("Lucy is needed for the Axe") end end

    -- add shining effect at first
    inst.AnimState:SetBloomEffectHandle( "shaders/anim.ksh" )
    inst.oncePickUpped = false

    inst.lucyCnt = 0
    inst.OnSave = onsave
    inst.OnLoad = onload

	updateStatus(inst)

    return inst
end

STRINGS.NAMES.BUSTERAXE = "Axe of Aisopos"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.BUSTERAXE = "It is a very wonderful gift!"

return  Prefab("common/inventory/busteraxe", fn, assets, prefabs)